(************************************************************************************
Filename    :   Win32_RoomTiny_Main.cpp
Content     :   First-person view test application for Oculus Rift
Created     :   18th Dec 2014
Authors     :   Tom Heath
Copyright   :   Copyright 2012 Oculus, Inc. All Rights reserved.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*************************************************************************************)
/// A sample to show a very intuitive jump mechanism by moving the Rift in an
/// upward motion on your head.  The jump is proportional to the magnitude of
/// your movement.
unit UDemoJumpFromAccelerometers;

interface

procedure Main;

implementation

uses
  Winapi.Windows, System.Math.Vectors, OVR_CAPI, UDirectXAppUtil, UBasicVR, UControlMethods;

type
  TJumpFromAccelerometers = class(TBasicVR)
  public
    constructor Create;
    procedure MainLoop; override;
  end;

constructor TJumpFromAccelerometers.Create;
begin
  inherited Create('Jump From Accelerometers');
end;

procedure TJumpFromAccelerometers.MainLoop;
var
  trackingState: TOvrTrackingState;
  eye: NativeInt;
begin
  Layer[0] := TVRLayer.Create(Session);

  while HandleMessages do
  begin
    ActionFromInput;

    trackingState := Layer[0].GetEyePoses;

    // Set jump from accelerometers y pos value into camera
    MainCam.Pos := Point3D(MainCam.Pos.X,
                           GetAccelJumpPosY(Self, trackingState),
                           MainCam.Pos.Z);

    for eye := 0 to 1 do
    begin
      Layer[0].RenderSceneToEyeBuffer(MainCam, RoomScene, eye);
    end;

    Layer[0].PrepareLayerHeader;
    DistortAndPresent(1);
  end;
end;

procedure Main;
var
  app: TJumpFromAccelerometers;
begin
  app := TJumpFromAccelerometers.Create;
  try
    ExitCode := app.Run;
  finally
    app.Free;
  end;
end;

end.